Transform Google Doc to Quarto book
Details
If your Google Document contains lists whose items span several lines,
you might get better results with the fix_lists parameter set to TRUE.
The problem is that in Google Docs lists, from the second line lines in items
have a small indentation. Pandoc tends to interpret this as a blockquote.
We try to fix that by merging blockquotes in their previous sibling,
when that previous sibling is a list item.
Examples
if (FALSE) { # interactive()
id <- googledrive::drive_find(
q = "name contains 'My Example Document'"
)$id
quarto_dir <- withr::local_tempdir()
quartificate::quartificate(id, quarto_dir, render = TRUE)
}